@@ -174,7 +174,7 @@ class Parser(_ConfigurationData):
     Public methods:
     print_all()
     """
-    def __init__(self, configuration_file_name = None, defaults = {}):
+    def __init__(self, configuration_file_name = None, defaults = {}, delimiter='='):
         """
         Read and parse configuration file.
 
@@ -186,6 +186,7 @@ class Parser(_ConfigurationData):
         import os
 
         self.prefix = '____' # set prefix that will be added to all dynamically added attributes
+        self.delimiter = str(delimiter)
 
         if configuration_file_name == None:
             raise ConfigurationFileError("You need to provide configuration file name or full path")
@@ -275,7 +276,7 @@ class Parser(_ConfigurationData):
                             except AttributeError:
                                 self[section_name] = _ConfigurationData()
                         try:
-                            k, v = l.split('=',1)
+                            k, v = l.split(self.delimiter, 1)
                         except ValueError:
                             raise ConfigurationParseError("At least one line of configuration file in not supported format!")
                         self[section_name][k.strip()] = v.strip()
